@@ -41,7 +41,7 @@ int main(int argc, char **argv)
                      KAboutLicense::GPL,
                      i18n("(C) 2002-2016 Carsten Niehaus & the KDE Edu Developers"),
                      QString(),
-                     QStringLiteral("https://edu.kde.org/kalzium"));
+                     QStringLiteral("https://apps.kde.org/kalzium"));
 
     about.addAuthor(i18n("Carsten Niehaus"), QString(), QStringLiteral("cniehaus@kde.org"));
 
@@ -89,9 +89,7 @@ int main(int argc, char **argv)
 
     about.addCredit(i18n("Etienne Rebetez"), i18n("Adding new sizable Periodic System"));
 
-    QApplication::setApplicationName(QStringLiteral("kalzium"));
-    QApplication::setApplicationVersion(KALZIUM_VERSION_STRING);
-    QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kalzium")));
 
     KAboutData::setApplicationData(about);
 
